import { ChangeEvent, MouseEvent } from 'react';

declare enum MaxFileSize {
    '1MB' = 1000000,
    '2MB' = 2000000,
    '3MB' = 3000000,
    '4MB' = 4000000,
    '5MB' = 5000000
}

declare enum EXTS {
    JPG = ".jpg",
    JPEG = ".jpeg",
    PNG = ".png",
    WEBP = ".webp",
    HEIC = ".heic",
    HEIF = ".heif"
}

/**
 * @function useFileChooser
 * a function which optionally accept the two params
 * @param exts EXTS[] | undefined
 * @param maxSize number | undefined
 *
 * @default exts ['.jpg', '.jpeg', '.png']
 * @default maxSize 1000000
 */
declare const useFileChooser: (exts?: EXTS[], maxSize?: number) => {
    isDragging: boolean;
    error: string;
    file: File | null;
    imageDataUrl: string;
    onChange: (e: ChangeEvent<HTMLInputElement> | React.DragEvent, isDragEvent: boolean) => void;
    onDrag: (e: React.DragEvent, dragging: boolean) => void;
    destroy: (e: MouseEvent) => void;
};

export { EXTS, MaxFileSize, useFileChooser };
